@@ -18,6 +18,8 @@
 #
 #    (C) 2005 Nicolas Évrard <nicoe@altern.org>
 
+__revision__ = "$Id: gnomolicious.py,v 1.6 2005/02/02 11:52:14 nicoe Exp $"
+
 import pygtk
 pygtk.require('2.0')
 import gtk
@@ -36,7 +38,6 @@ from time import time as now
 import delicious
 import conf
 
-GCONF_PATH = "/apps/del.icio.us"
 logger = logging.getLogger('gnomolicious')
 
 def findMatchingTag(completion, key_string, cursor, column):
@@ -45,6 +46,58 @@ def findMatchingTag(completion, key_string, cursor, column):
     text = model.get_value(cursor, column)
     return text.startswith(lastword)
 
+class GnomoliciousConfiguration(object):
+    
+    GCONF_PATH = "/apps/gnomolicious"
+    
+    def __init__(self):
+        self.__gconf = gconf.client_get_default()
+        self.__gconf.add_dir(self.GCONF_PATH, gconf.CLIENT_PRELOAD_RECURSIVE)
+        
+    def getUsername(self):
+        return self.__gconf.get_string(self.GCONF_PATH + '/username')
+
+    def setUsername(self, user):
+        self.__gconf.set_string(self.GCONF_PATH + '/username', user)
+
+    username = property(getUsername, setUsername)
+
+    def getPassword(self):
+        return self.__gconf.get_string(self.GCONF_PATH + '/password')
+
+    def setPassword(self, password):
+        self.__gconf.set_string(self.GCONF_PATH + '/password', password)
+
+    password = property(getPassword, setPassword)
+
+    def getUpdateInterval(self):
+        return self.__gconf.get_int(self.GCONF_PATH + '/update_interval')
+
+    def setUpdateInterval(self, interval):
+        self.__gconf.set_int(self.GCONF_PATH + '/update_interval', interval)
+
+    update_interval = property(getUpdateInterval, setUpdateInterval)
+
+    def getCommonTagColor(self):
+        return self.__gconf.get_string(self.GCONF_PATH + '/common_tag_color')
+
+    def setCommonTagColor(self, color):
+        self.__gconf.set_string(self.GCONF_PATH + '/common_tag_color',
+                color)
+
+    common_tag_color = property(getCommonTagColor, setCommonTagColor)
+
+    def getPopTagNum(self):
+        return self.__gconf.get_int(self.GCONF_PATH + '/pop_tag_num')
+
+    def setPopTagNum(self, num):
+        self.__gconf.set_int(self.GCONF_PATH + '/pop_tag_num', num)
+
+    pop_tag_num = property(getPopTagNum, setPopTagNum)
+
+    def sync(self):
+        self.__gconf.suggest_sync()
+
 class GnomoliciousApplet(gnome.applet.Applet):
     
     title_re = re.compile('<title>(?P<title>.*)</title>',
@@ -57,10 +110,7 @@ class GnomoliciousApplet(gnome.applet.Applet):
         #        GNOME initialization stuffs        #
         #############################################
         self.__gobject_init__()
-
-        # gconf initilization
-        self.conf = gconf.client_get_default()
-        self.conf.add_dir(GCONF_PATH, gconf.CLIENT_PRELOAD_RECURSIVE)
+        self.conf = GnomoliciousConfiguration()
         
         # Popup-menu definition and popup-menu callbacks
         self.propxml="""\
@@ -114,7 +164,8 @@ class GnomoliciousApplet(gnome.applet.Applet):
             'ext' : wT.get_widget('entry_ext'),
             'popular' : wT.get_widget('populartable') }
         self.populartags_buttons = {}
-        self.populartags_nobuttons = gtk.Label(_('No popular tags retrieved for this URL'))
+        self.populartags_nobuttons = gtk.Label(
+            _('No popular tags retrieved for this URL'))
         self.postwin.completion = gtk.EntryCompletion()
         self.postwin.entries['tags'].set_completion(self.postwin.completion)
         self.tags = gtk.ListStore(str, str)
@@ -133,7 +184,11 @@ class GnomoliciousApplet(gnome.applet.Applet):
         self.prefwin = wT.get_widget('window_pref')
         self.prefwin.entries = {
             'password' : wT.get_widget('entry_password'),
-            'username' : wT.get_widget('entry_username') }
+            'username' : wT.get_widget('entry_username'),
+            'commontagcolor' : wT.get_widget('entry_commontagcolor'),
+            'updatetime' : wT.get_widget('entry_updatetime'),
+            'maxpoptag' : wT.get_widget('entry_numpoptag'),
+            }
         
         wT.signal_autoconnect(self)
 
@@ -142,14 +197,13 @@ class GnomoliciousApplet(gnome.applet.Applet):
         del self.applet
 
     def update_tags(self):
-        username = self.conf.get_string(GCONF_PATH + '/username')
-        password = self.conf.get_string(GCONF_PATH + '/password')
-        logger.debug('Last update: %s' % (now() - self.last_update))
-        if username and password and (now() - self.last_update) > 30*60 :
+        if (self.conf.username and self.conf.password and
+            (now() - self.last_update) > self.conf.update_interval*60) :
             logger.info('Updating your tags')
             self.last_update = now()
             self.tags.clear()
-            taglist = delicious.get_tags(username, password)
+            taglist = delicious.get_tags(self.conf.username,
+                                         self.conf.password)
             for tagdict in taglist:
                 logger.debug('Adding: %s' % tagdict['tag'])
                 if int(tagdict['count']) > 1:
@@ -172,8 +226,7 @@ class GnomoliciousApplet(gnome.applet.Applet):
                 0, 15, 0, 5)
 
     def clear_prefwin(self):
-        self.prefwin.entries['password'].set_text('')
-        self.prefwin.entries['username'].set_text('')
+        pass
 
     def get_poptags(self, url):
         tags = {}
@@ -192,7 +245,7 @@ class GnomoliciousApplet(gnome.applet.Applet):
             self.postwin.entries['popular'].remove(self.populartags_nobuttons)
         for tag, num in tags:
             if tag in [x[0] for x in self.tags]:
-                color = "blue"
+                color = self.conf.common_tag_color
             else:
                 color = "black"
             btn = gtk.CheckButton(tag, False)
@@ -217,10 +270,16 @@ class GnomoliciousApplet(gnome.applet.Applet):
         self.postwin.show_all()
 
     def preferences(self, evt, data=None):
-        username = self.conf.get_string(GCONF_PATH + '/username')
-        password = self.conf.get_string(GCONF_PATH + '/password')
-        self.prefwin.entries['username'].set_text(username)
-        self.prefwin.entries['password'].set_text(password)
+        username = self.conf.username
+        password = self.conf.password
+        if username:
+            self.prefwin.entries['username'].set_text(username)
+        if password:
+            self.prefwin.entries['password'].set_text(password)
+        self.prefwin.entries['updatetime'].set_value(self.conf.update_interval)
+        self.prefwin.entries['commontagcolor'].set_color(
+            gtk.gdk.color_parse(self.conf.common_tag_color))
+        self.prefwin.entries['maxpoptag'].set_value(self.conf.pop_tag_num)
         self.prefwin.show()
 
     def about(self, evt, data=None):
@@ -280,20 +339,23 @@ class GnomoliciousApplet(gnome.applet.Applet):
         ext = buff.get_text(buff.get_start_iter(), buff.get_end_iter())
         logger.info('URL: %s' % url)
         logger.info('Tags: %s' % tags)
-        username = self.conf.get_string(GCONF_PATH + '/username')
-        password = self.conf.get_string(GCONF_PATH + '/password')
-        delicious.add(username, password, url, desc, ext, tags)
+        delicious.add(self.conf.username,
+                      self.conf.password, url, desc, ext, tags)
         logger.info('Posting done')
         self.postwin.hide()
         self.clear_postwin()
         return gtk.TRUE
 
     def on_setpref(self, evt, data=None):
-        username = self.prefwin.entries['username'].get_text()
-        self.conf.set_string(GCONF_PATH + '/username', username)
-        password = self.prefwin.entries['password'].get_text()
-        self.conf.set_string(GCONF_PATH + '/password', password)
-        self.conf.suggest_sync()
+        self.conf.username = self.prefwin.entries['username'].get_text()
+        self.conf.password = self.prefwin.entries['password'].get_text()
+        self.conf.update_interval = self.prefwin.entries['updatetime'].get_value_as_int()
+        color = self.prefwin.entries['commontagcolor'].get_color()
+        self.conf.common_tag_color = '#%04x%04x%04x' % (color.red,
+                color.green, color.blue)
+        self.conf.pop_tag_num = self.prefwin.entries['maxpoptag'].get_value_as_int()
+
+        self.conf.sync()
         self.prefwin.hide()
         return gtk.TRUE
 
@@ -326,3 +388,7 @@ class GnomoliciousApplet(gnome.applet.Applet):
                     btn = self.populartags_buttons[tag]
                     btn.set_active(True)
         return gtk.FALSE
+
+    def on_register_clicked(self, evt, data=None):
+        gnome.url_show('http://del.icio.us/register')
+        return gtk.TRUE
